import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl =
  'https://gist.githubusercontent.com/Mukunda799/56125cfa3b9647c7f761372e1fff9500/raw/b1a4cea4ea1abd489739e468b1267b586d9824c5/countrydata.csv';

const parseRow = (d) => {
  const years = Object.keys(d).filter(
    (key) => !isNaN(+key),
  );
  return {
    Country: d.Country,
    data: years.map((year) => ({
      year: +year,
      value: +d[year],
    })),
  };
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('#scatterplot-container')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.data[0].value) // Initial x value, you may change this
    .yValue((d) => d.data[d.data.length - 1].value) // Initial y value, you may change this
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(5);

  svg.call(plot);

  // Example of updating the scatter plot data
  // You can modify this part as needed
  // For instance, you can add interaction to update the plot
  // based on user input or events
  setInterval(() => {
    const randomIndex = Math.floor(
      Math.random() * plot.data().length,
    );
    const newData = plot.data().map((d, i) => {
      if (i === randomIndex) {
        // Randomize data for demonstration
        d.data.forEach((entry) => {
          entry.value = Math.random() * 80000; // Assuming maximum value around 80000
        });
      }
      return d;
    });
    plot.data(newData);
    svg.call(plot);
  }, 2000);
};
main();
